/**
 * JASMINe
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JkManagerService.java 7029 2010-10-28 23:16:01Z pelletib $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.agent.common.jk;

/**
 * The interface describing the JkManagerService available on a host to change the configuration of the mod_jk plugin.
 *
 * @author Julien Vey
 */
public interface JkManagerService {

    /**
     * @param name
     *            the name of the worker
     * @param host
     *            the host of the worker
     * @param port
     *            the port of the worker
     * @param type
     *            the type of the connector
     */
    void addNamedWorker(String name, String host, String port, String type);

    /**
     * @param name
     *            the name of the worker
     * @param host
     *            the host to add
     * @param port
     *            the port of the host
     * @param type
     *            the type of the connector
     * @param lbFactor
     *            the load balancing factor
     */
    void addNamedWorker(String name, String host, String port, String type, String lbFactor);

    /**
     * @param host
     *            the host to add
     * @param port
     *            the port of the host
     * @param type
     *            the type of the connector
     */
    void addWorker(String host, String port, String type);

    /**
     * @param host
     *            the host to add
     * @param port
     *            the port of the host
     * @param type
     *            the type of the connector
     * @param lbFactor
     *            the load balancing factor
     */
    void addWorker(String host, String port, String type, String lbFactor);

    /**
     * Remove a named worker
     * @param name
     *            the name of the worker
     */
    void removeNamedWorker(String name);

    /**
     * Disable a named worker
     * @param name
     *            the name of the worker
     */
    void disableNamedWorker(String name);

    /**
     * Enable a named worker
     * @param name
     *            the name of the worker
     */
    void enableNamedWorker(String name);

    /**
     * Stop a named worker
     * @param name
     *            the name of the worker
     */
    void stopNamedWorker(String name);


    /**
     * reload apache2 configuration
     */
    void reload();

    /**
     * init configuration
     */
    void init(String workersConfigurationFile, String reloadCmd);


    /**
     * @return true if configured
     * @param name
     *            the name of the worker
     */
    boolean isConfigured(String name);

    /**
     * @return true if enabled
     * @param name
     *            the name of the worker
     */
    boolean isEnabled(String name);

    /**
     * get the id of the service (corresponding to the agent id)
     *
     * @return the id of the service
     */
    String getId();
}
